#[repr(u8)]pub enum SampMode {
SAMP_MODE_0 = 0,
SAMP_MODE_1 = 1,
SAMP_MODE_2 = 2,
SAMP_MODE_3 = 3,
}Variants
SAMP_MODE_0 = 0
use Von Neumann data into both Entropy shifter and Statistical Checker
SAMP_MODE_1 = 1
use raw data into both Entropy shifter and Statistical Checker
SAMP_MODE_2 = 2
use Von Neumann data into Entropy shifter. Use raw data into Statistical Checker
SAMP_MODE_3 = 3
undefined/reserved.
Implementations